Module: Google::Cloud::VpcAccess
- Defined in:
- lib/google/cloud/vpc_access.rb,
lib/google/cloud/vpc_access/version.rb
Constant Summary collapse
- VERSION =
"1.7.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.vpc_access| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-vpc_access library.
-
.vpc_access_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for VpcAccessService.
-
.vpc_access_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the VpcAccessService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.vpc_access| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-vpc_access library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
149 150 151 152 153 |
# File 'lib/google/cloud/vpc_access.rb', line 149 def self.configure yield ::Google::Cloud.configure.vpc_access if block_given? ::Google::Cloud.configure.vpc_access end |
.vpc_access_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for VpcAccessService.
By default, this returns an instance of
Google::Cloud::VpcAccess::V1::VpcAccessService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the VpcAccessService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the VpcAccessService service. You can determine whether the method will succeed by calling vpc_access_service_available?.
About VpcAccessService
Serverless VPC Access API allows users to create and manage connectors for App Engine, Cloud Functions and Cloud Run to have internal connections to Virtual Private Cloud networks.
77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/google/cloud/vpc_access.rb', line 77 def self.vpc_access_service version: :v1, transport: :grpc, &block require "google/cloud/vpc_access/#{version.to_s.downcase}" package_name = Google::Cloud::VpcAccess .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::VpcAccess.const_get(package_name).const_get(:VpcAccessService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.vpc_access_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the VpcAccessService service is supported by the current client. If true, you can retrieve a client object by calling vpc_access_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the VpcAccessService service, or if the versioned client gem needs an update to support the VpcAccessService service.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/google/cloud/vpc_access.rb', line 101 def self.vpc_access_service_available? version: :v1, transport: :grpc require "google/cloud/vpc_access/#{version.to_s.downcase}" package_name = Google::Cloud::VpcAccess .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::VpcAccess.const_get package_name return false unless service_module.const_defined? :VpcAccessService service_module = service_module.const_get :VpcAccessService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |